import torch.nn as nn
import torch.nn.functional as F

class Net(nn.Module):
    def __init__(self, 
        conv1_out_channels=20, conv1_kernel=5,
        conv2_out_channels=50, conv2_kernel=5,
        fc1_in_dim=4*4*50, fc1_out_dim=500,
        **kwargs
        ):
        super(Net, self).__init__()
        self.conv1 = nn.Conv2d(1, conv1_out_channels, conv1_kernel, 1)
        self.conv2 = nn.Conv2d(conv1_out_channels, conv2_out_channels, conv2_kernel, 1)
        self.fc1 = nn.Linear(fc1_in_dim, fc1_out_dim)
        self.fc2 = nn.Linear(fc1_out_dim, 10)
        self.fc1_in_dim = fc1_in_dim

    def forward(self, x):
        x = F.relu(self.conv1(x))
        x = F.max_pool2d(x, 2, 2)
        x = F.relu(self.conv2(x))
        x = F.max_pool2d(x, 2, 2)
        x = x.view(-1, self.fc1_in_dim)
        x = F.relu(self.fc1(x))
        x = self.fc2(x)
        return F.log_softmax(x, dim=1)

